@@ -15,14 +15,14 @@ around headline => sub {
 sub journalist {
     my ($self) = @_;
     my $el = $self->dom->at('.article-info');
-    my ($n) = $el->all_text =~ m{^撰文: (?:(?:特約)?記者)?(\p{Letter}+?) \|};
+    my ($n) = $el->all_text =~ m{^(?:Author|撰文): (?:(?:特約)?記者)?(.+?) \|};
     return $n;
 }
 
 sub dateline {
     my ($self) = @_;
     my $el = $self->dom->at('.article-info');
-    my ($dd,$mm,$yy) = $el->all_text =~ m{發佈日期:\s([0-9]{2})\.([0-9]{2})\.([0-9]{2})\b};
+    my ($dd,$mm,$yy) = $el->all_text =~ m{(?:發佈日期|Publish Date):\s([0-9]{2})\.([0-9]{2})\.([0-9]{2})\b};
     return undef unless ($dd && $mm && $yy);
     return "20${yy}-${mm}-${dd}T23:59:59+08:00";
 }
